From: David Engraf <david.engraf@sysgo.com>
To: Dmitry Torokhov <dmitry.torokhov@gmail.com>
Cc: linux-input@vger.kernel.org, linux-kernel@vger.kernel.org
Subject: Re: [PATCH] serio: allow registered drivers to get status flag
Date: Thu, 20 Jan 2011 10:05:51 +0100 [thread overview]
Message-ID: <4D37FAEF.8080504@sysgo.com> (raw)
In-Reply-To: <20110118195710.GA27152@core.coreip.homeip.net>
[-- Attachment #1: Type: text/plain, Size: 1651 bytes --]
Am 18.01.2011 20:57, schrieb Dmitry Torokhov:
> On Tue, Jan 18, 2011 at 01:57:21PM +0100, David Engraf wrote:
>> Parse the status byte information to the registered serio drivers as
>> well as the character bytes.
>>
>> Signed-off-by: David Engraf<david.engraf@sysgo.com>
>>
>
>> --- linux-2.6.37/drivers/input/serio/serport.c.orig 2011-01-18 12:33:41.421709232 +0100
>> +++ linux-2.6.37/drivers/input/serio/serport.c 2011-01-18 13:33:24.521711214 +0100
>> @@ -116,8 +116,8 @@ static void serport_ldisc_close(struct t
>>
>> /*
>> * serport_ldisc_receive() is called by the low level tty driver when characters
>> - * are ready for us. We forward the characters, one by one to the 'interrupt'
>> - * routine.
>> + * are ready for us. We forward the characters and flags, one by one to the
>> + * 'interrupt' routine.
>> */
>>
>> static void serport_ldisc_receive(struct tty_struct *tty, const unsigned char *cp, char *fp, int count)
>> @@ -132,7 +132,7 @@ static void serport_ldisc_receive(struct
>> goto out;
>>
>> for (i = 0; i< count; i++)
>> - serio_interrupt(serport->serio, cp[i], 0);
>> + serio_interrupt(serport->serio, cp[i], fp[i]);
>>
>
> Hi David,
>
> The flags argument that serio_interrupt() accepts not the raw protocol
> data, but sanitized, protocol-independent SERIO_TIMEOUT, SERIO_PARITY
> and SERIO_FRAME bits.
>
> Thanks.
>
Hi Dmitry,
I've updated the patch so that the raw protocol is converted to the
SERIO_ bits. The raw protocol can parse only one flag, so I don't need
to store multiple SERIO_ bits in the character flag variable.
Thanks
- David
Signed-off-by: David Engraf<david.engraf@sysgo.com>
[-- Attachment #2: serport_parse_flags.diff --]
[-- Type: text/x-diff, Size: 1282 bytes --]
--- linux-2.6.37/drivers/input/serio/serport.c.orig 2011-01-18 12:33:41.421709232 +0100
+++ linux-2.6.37/drivers/input/serio/serport.c 2011-01-20 09:55:53.849550065 +0100
@@ -116,14 +116,15 @@ static void serport_ldisc_close(struct t
/*
* serport_ldisc_receive() is called by the low level tty driver when characters
* are ready for us. We forward the characters, one by one to the 'interrupt'
* routine.
*/
static void serport_ldisc_receive(struct tty_struct *tty, const unsigned char *cp, char *fp, int count)
{
struct serport *serport = (struct serport*) tty->disc_data;
unsigned long flags;
+ unsigned int ch_flags;
int i;
spin_lock_irqsave(&serport->lock, flags);
@@ -131,8 +132,15 @@ static void serport_ldisc_receive(struct
if (!test_bit(SERPORT_ACTIVE, &serport->flags))
goto out;
- for (i = 0; i < count; i++)
- serio_interrupt(serport->serio, cp[i], 0);
+ for (i = 0; i < count; i++) {
+ ch_flags = 0;
+ if (fp[i] == TTY_FRAME)
+ ch_flags = SERIO_FRAME;
+ else if (fp[i] == TTY_PARITY)
+ ch_flags = SERIO_PARITY;
+
+ serio_interrupt(serport->serio, cp[i], ch_flags);
+ }
out:
spin_unlock_irqrestore(&serport->lock, flags);
next prev parent reply other threads:[~2011-01-20 9:05 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2011-01-18 12:57 [PATCH] serio: allow registered drivers to get status flag David Engraf
2011-01-18 19:57 ` Dmitry Torokhov
2011-01-20 9:05 ` David Engraf [this message]
2011-01-26 9:36 ` David Engraf
2011-01-26 17:00 ` Dmitry Torokhov
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=4D37FAEF.8080504@sysgo.com \
--to=david.engraf@sysgo.com \
--cc=dmitry.torokhov@gmail.com \
--cc=linux-input@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -116,14 +116,15 @@ static void serport_ldisc_close(struct t
/*
* serport_ldisc_receive() is called by the low level tty driver when characters
- * are ready for us. We forward the characters, one by one to the 'interrupt'
- * routine.
+ * are ready for us. We forward the characters and flags, one by one to the
+ * 'interrupt' routine.
*/
static void serport_ldisc_receive(struct tty_struct *tty, const unsigned char *cp, char *fp, int count)
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.